@@ -22,7 +22,7 @@ from zope.lifecycleevent import IObjectCreatedEvent, ObjectCreatedEvent
 from zope.schema import Bool, Choice, Datetime, Int, List, Object, Set, Text, TextLine
 from zope.schema.vocabulary import SimpleTerm, SimpleVocabulary
 
-from pyams_security.interfaces.base import VIEW_PERMISSION
+from pyams_security.interfaces.base import PUBLIC_PERMISSION
 from pyams_security.schema import PrincipalField
 
 
@@ -407,8 +407,11 @@ class IWorkflowVersions(Interface):
 
     last_version_id = Attribute("Last version ID")
 
-    def get_version(self, version_id):
-        """Get version matching given id"""
+    def get_version(self, version_id=None):
+        """Get version matching given id
+
+        If version ID is None or equals -1, method returns the last version.
+        """
 
     def get_versions(self, states=None, sort=False, reverse=False):
         """Get all versions of object known for this (optional) state"""
@@ -456,7 +459,7 @@ class IWorkflowManagedContent(IAttributeAnnotatable):
     view_permission = Choice(title=_("View permission"),
                              description=_("This permission will be required to display content"),
                              vocabulary='PyAMS permissions',
-                             default=VIEW_PERMISSION,
+                             default=PUBLIC_PERMISSION,
                              required=False)
 
 
@@ -471,6 +474,9 @@ VERSION_DISPLAY = {
     DISPLAY_CURRENT_VERSION: _("Display current version date")
 }
 
+DISPLAY_UNVERSIONED = _("Display content publication date")
+
+
 VERSION_DISPLAY_VOCABULARY = SimpleVocabulary([
     SimpleTerm(v, title=t) for v, t in VERSION_DISPLAY.items()
 ])
